------------------------------------------------------------------------------
--  Test: Session_Handling_001
--  Verification: This test verifies that default maximum number of connections
--      for all logins is 1
--
--  Test Details:
--      1.  The default max number of connections will be verified
--
--  Test Dependenices:
--      1.  This test must be executed as a sysadmin
------------------------------------------------------------------------------

DECLARE @error_message 	nvarchar(1024)

BEGIN TRY
	SET NOCOUNT ON

	------------------------------------------------------------------------------
	-- If the version is not correct then do not run the script
	------------------------------------------------------------------------------
	IF SERVERPROPERTY( N'ProductVersion' ) <> N'10.50.2500.0'
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_001] This test can only be executed on SQL Server 2008 R2 SP1';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify test dependencies
	------------------------------------------------------------------------------
	IF ( IS_SRVROLEMEMBER( N'sysadmin' ) = 0 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_001] This test must be executed by a sysadmin';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify default value
	------------------------------------------------------------------------------
	IF ( ( SELECT count(*) FROM [dbo].[maximum_number_of_connections_per_login_A54E382458CA11DB8373B622A1EF5492] ) <> 1 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_001] Max number of connections is not set or has too many rows';
		PRINT @error_message
		RETURN;
	END

	IF ( ( SELECT max_connections FROM [dbo].[maximum_number_of_connections_per_login_A54E382458CA11DB8373B622A1EF5492] ) <> 5 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_001] Max number of connections is not set to 1';
		PRINT @error_message
		RETURN;
	END

	PRINT 'TESTRESULT: PASS [Session_Handling_001]';
END TRY
BEGIN CATCH

	SET @error_message = N'TESTRESULT: FAIL [Session_Handling_001] ' + error_message();
	PRINT @error_message

END CATCH
go

