------------------------------------------------------------------------------
--  Test: Session_Handling_007
--  Verification: This test verifies the login statistics for LGN_Session_Handling
--
--  Test Details:
--      1.  Verify the statistics for all Session Handling Tests
--
--  Test Dependenices:
--      1.  This test must be executed by LGN_Session_Handling
--      2.  The entire suite of tests for session handling must have been executed
------------------------------------------------------------------------------

DECLARE @error_message 	nvarchar(1024)

BEGIN TRY
	SET NOCOUNT ON

	------------------------------------------------------------------------------
	-- If the version is not correct then do not run the script
	------------------------------------------------------------------------------
	IF SERVERPROPERTY( N'ProductVersion' ) <> N'10.50.2500.0'
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_007] This test can only be executed on SQL Server 2008 R2 SP1';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify test dependencies
	------------------------------------------------------------------------------
	IF ( SUSER_SNAME() <> N'LGN_Session_Handling' )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_005] This test must execute as the LGN_Session_Handling sql login';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify number of failed connections
	------------------------------------------------------------------------------
	IF ( ( SELECT unsuccessful_logons FROM [sys].[dm_exec_sessions] WHERE original_login_name = N'LGN_Session_Login' ) <> 2 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_007] The number of unsuccessful logons is incorrect';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify time of last failed connection
	------------------------------------------------------------------------------
	IF ( ( SELECT DATEDIFF( mi, last_unsuccessful_logon, GETDATE() ) FROM [sys].[dm_exec_sessions] WHERE original_login_name = N'LGN_Session_Login' ) > 1 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_007] The time of the last unsuccessful logon is incorrect';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify time of last successful connection
	------------------------------------------------------------------------------
	IF ( ( SELECT DATEDIFF( mi, last_successful_logon, GETDATE() ) FROM [sys].[dm_exec_sessions] WHERE original_login_name = N'LGN_Session_Login' ) > 1 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_007] The time of the last successful logon is incorrect';
		PRINT @error_message
		RETURN;
	END

	PRINT 'TESTRESULT: PASS [Session_Handling_007]';
END TRY
BEGIN CATCH

	SET @error_message = N'TESTRESULT: FAIL [Session_Handling_007] ' + error_message();
	PRINT @error_message

END CATCH
go

